==> skill-service-15.0.1-sources.jar: dbscript/modules.sql <==

		
				        
	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('sms', 'sms', '/web/c/sms', '0', 'web');
	
				        
	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('user', 'user', '/web/c/user', '0', 'web');
	
				        
	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('userClassRelation', 'userClassRelation', '/web/c/userClassRelation', '0', 'web');
	
				        
	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('comment', 'comment', '/web/c/comment', '0', 'web');
	
				        
	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('occupation', 'occupation', '/web/c/occupation', '0', 'web');
	
				        
	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('article', 'article', '/web/c/article', '0', 'web');
	
				        
	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('class', 'class', '/web/c/class', '0', 'web');



	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('userScore', 'userScore', '/web/c/userScore', '0', 'web');



	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('leaves', 'leaves', '/web/c/leaves', '0', 'web');


	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('constant', 'constant', '/web/c/constant', '0', 'web');

	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('userStatistics', 'userStatistics', '/web/c/userStatistics', '0', 'web');

==> skill-service-18.0.2-sources.jar: dbscript/modules.sql <==

		
				        
	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('sms', 'sms', '/web/c/sms', '0', 'web');
	
				        
	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('user', 'user', '/web/c/user', '0', 'web');
	
				        
	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('userClassRelation', 'userClassRelation', '/web/c/userClassRelation', '0', 'web');
	
				        
	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('comment', 'comment', '/web/c/comment', '0', 'web');
	
				        
	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('occupation', 'occupation', '/web/c/occupation', '0', 'web');
	
				        
	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('article', 'article', '/web/c/article', '0', 'web');
	
				        
	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('class', 'class', '/web/c/class', '0', 'web');



	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('userScore', 'userScore', '/web/c/userScore', '0', 'web');



	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('leaves', 'leaves', '/web/c/leaves', '0', 'web');


	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('constant', 'constant', '/web/c/constant', '0', 'web');

	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('userStatistics', 'userStatistics', '/web/c/userStatistics', '0', 'web');



	        INSERT INTO `module`(name,menu_id,url,parent_id,type)  VALUES ('stage', 'stage', '/web/c/stage', '0', 'web');
